====
elen
====


.. image:: https://img.shields.io/pypi/v/elen.svg
        :target: https://pypi.python.org/pypi/elen

.. image:: https://img.shields.io/travis/rooterkyberian/elen.svg
        :target: https://travis-ci.org/rooterkyberian/elen

.. image:: https://readthedocs.org/projects/elen/badge/?version=latest
        :target: https://elen.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/rooterkyberian/elen/shield.svg
     :target: https://pyup.io/repos/github/rooterkyberian/elen/
     :alt: Updates


Efficient Lexicographic Encoding of Numbers for python.
Based on ELEN algorithm published by Peter Seymour, http://www.zanopha.com/docs/elen.pdf .

* Free software: MIT license
* Documentation: https://elen.readthedocs.io.


Features
--------

* two-way conversion between ELEN notation and Python `decimal.Decimal` instance
